# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class AnalyticsLicenseCustomDataFieldLabels(object):
    @poscheck_model
    def __init__(self,
                 custom_data1=None,
                 custom_data2=None,
                 custom_data3=None,
                 custom_data4=None,
                 custom_data5=None,
                 custom_data6=None,
                 custom_data7=None,
                 custom_data8=None,
                 custom_data9=None,
                 custom_data10=None,
                 custom_data11=None,
                 custom_data12=None,
                 custom_data13=None,
                 custom_data14=None,
                 custom_data15=None,
                 custom_data16=None,
                 custom_data17=None,
                 custom_data18=None,
                 custom_data19=None,
                 custom_data20=None,
                 custom_data21=None,
                 custom_data22=None,
                 custom_data23=None,
                 custom_data24=None,
                 custom_data25=None,
                 custom_data26=None,
                 custom_data27=None,
                 custom_data28=None,
                 custom_data29=None,
                 custom_data30=None,
                 custom_data31=None,
                 custom_data32=None,
                 custom_data33=None,
                 custom_data34=None,
                 custom_data35=None,
                 custom_data36=None,
                 custom_data37=None,
                 custom_data38=None,
                 custom_data39=None,
                 custom_data40=None,
                 custom_data41=None,
                 custom_data42=None,
                 custom_data43=None,
                 custom_data44=None,
                 custom_data45=None,
                 custom_data46=None,
                 custom_data47=None,
                 custom_data48=None,
                 custom_data49=None,
                 custom_data50=None):
        # type: (string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types, string_types) -> None

        self._custom_data1 = None
        self._custom_data2 = None
        self._custom_data3 = None
        self._custom_data4 = None
        self._custom_data5 = None
        self._custom_data6 = None
        self._custom_data7 = None
        self._custom_data8 = None
        self._custom_data9 = None
        self._custom_data10 = None
        self._custom_data11 = None
        self._custom_data12 = None
        self._custom_data13 = None
        self._custom_data14 = None
        self._custom_data15 = None
        self._custom_data16 = None
        self._custom_data17 = None
        self._custom_data18 = None
        self._custom_data19 = None
        self._custom_data20 = None
        self._custom_data21 = None
        self._custom_data22 = None
        self._custom_data23 = None
        self._custom_data24 = None
        self._custom_data25 = None
        self._custom_data26 = None
        self._custom_data27 = None
        self._custom_data28 = None
        self._custom_data29 = None
        self._custom_data30 = None
        self._custom_data31 = None
        self._custom_data32 = None
        self._custom_data33 = None
        self._custom_data34 = None
        self._custom_data35 = None
        self._custom_data36 = None
        self._custom_data37 = None
        self._custom_data38 = None
        self._custom_data39 = None
        self._custom_data40 = None
        self._custom_data41 = None
        self._custom_data42 = None
        self._custom_data43 = None
        self._custom_data44 = None
        self._custom_data45 = None
        self._custom_data46 = None
        self._custom_data47 = None
        self._custom_data48 = None
        self._custom_data49 = None
        self._custom_data50 = None
        self.discriminator = None

        if custom_data1 is not None:
            self.custom_data1 = custom_data1
        if custom_data2 is not None:
            self.custom_data2 = custom_data2
        if custom_data3 is not None:
            self.custom_data3 = custom_data3
        if custom_data4 is not None:
            self.custom_data4 = custom_data4
        if custom_data5 is not None:
            self.custom_data5 = custom_data5
        if custom_data6 is not None:
            self.custom_data6 = custom_data6
        if custom_data7 is not None:
            self.custom_data7 = custom_data7
        if custom_data8 is not None:
            self.custom_data8 = custom_data8
        if custom_data9 is not None:
            self.custom_data9 = custom_data9
        if custom_data10 is not None:
            self.custom_data10 = custom_data10
        if custom_data11 is not None:
            self.custom_data11 = custom_data11
        if custom_data12 is not None:
            self.custom_data12 = custom_data12
        if custom_data13 is not None:
            self.custom_data13 = custom_data13
        if custom_data14 is not None:
            self.custom_data14 = custom_data14
        if custom_data15 is not None:
            self.custom_data15 = custom_data15
        if custom_data16 is not None:
            self.custom_data16 = custom_data16
        if custom_data17 is not None:
            self.custom_data17 = custom_data17
        if custom_data18 is not None:
            self.custom_data18 = custom_data18
        if custom_data19 is not None:
            self.custom_data19 = custom_data19
        if custom_data20 is not None:
            self.custom_data20 = custom_data20
        if custom_data21 is not None:
            self.custom_data21 = custom_data21
        if custom_data22 is not None:
            self.custom_data22 = custom_data22
        if custom_data23 is not None:
            self.custom_data23 = custom_data23
        if custom_data24 is not None:
            self.custom_data24 = custom_data24
        if custom_data25 is not None:
            self.custom_data25 = custom_data25
        if custom_data26 is not None:
            self.custom_data26 = custom_data26
        if custom_data27 is not None:
            self.custom_data27 = custom_data27
        if custom_data28 is not None:
            self.custom_data28 = custom_data28
        if custom_data29 is not None:
            self.custom_data29 = custom_data29
        if custom_data30 is not None:
            self.custom_data30 = custom_data30
        if custom_data31 is not None:
            self.custom_data31 = custom_data31
        if custom_data32 is not None:
            self.custom_data32 = custom_data32
        if custom_data33 is not None:
            self.custom_data33 = custom_data33
        if custom_data34 is not None:
            self.custom_data34 = custom_data34
        if custom_data35 is not None:
            self.custom_data35 = custom_data35
        if custom_data36 is not None:
            self.custom_data36 = custom_data36
        if custom_data37 is not None:
            self.custom_data37 = custom_data37
        if custom_data38 is not None:
            self.custom_data38 = custom_data38
        if custom_data39 is not None:
            self.custom_data39 = custom_data39
        if custom_data40 is not None:
            self.custom_data40 = custom_data40
        if custom_data41 is not None:
            self.custom_data41 = custom_data41
        if custom_data42 is not None:
            self.custom_data42 = custom_data42
        if custom_data43 is not None:
            self.custom_data43 = custom_data43
        if custom_data44 is not None:
            self.custom_data44 = custom_data44
        if custom_data45 is not None:
            self.custom_data45 = custom_data45
        if custom_data46 is not None:
            self.custom_data46 = custom_data46
        if custom_data47 is not None:
            self.custom_data47 = custom_data47
        if custom_data48 is not None:
            self.custom_data48 = custom_data48
        if custom_data49 is not None:
            self.custom_data49 = custom_data49
        if custom_data50 is not None:
            self.custom_data50 = custom_data50

    @property
    def openapi_types(self):
        types = {
            'custom_data1': 'string_types',
            'custom_data2': 'string_types',
            'custom_data3': 'string_types',
            'custom_data4': 'string_types',
            'custom_data5': 'string_types',
            'custom_data6': 'string_types',
            'custom_data7': 'string_types',
            'custom_data8': 'string_types',
            'custom_data9': 'string_types',
            'custom_data10': 'string_types',
            'custom_data11': 'string_types',
            'custom_data12': 'string_types',
            'custom_data13': 'string_types',
            'custom_data14': 'string_types',
            'custom_data15': 'string_types',
            'custom_data16': 'string_types',
            'custom_data17': 'string_types',
            'custom_data18': 'string_types',
            'custom_data19': 'string_types',
            'custom_data20': 'string_types',
            'custom_data21': 'string_types',
            'custom_data22': 'string_types',
            'custom_data23': 'string_types',
            'custom_data24': 'string_types',
            'custom_data25': 'string_types',
            'custom_data26': 'string_types',
            'custom_data27': 'string_types',
            'custom_data28': 'string_types',
            'custom_data29': 'string_types',
            'custom_data30': 'string_types',
            'custom_data31': 'string_types',
            'custom_data32': 'string_types',
            'custom_data33': 'string_types',
            'custom_data34': 'string_types',
            'custom_data35': 'string_types',
            'custom_data36': 'string_types',
            'custom_data37': 'string_types',
            'custom_data38': 'string_types',
            'custom_data39': 'string_types',
            'custom_data40': 'string_types',
            'custom_data41': 'string_types',
            'custom_data42': 'string_types',
            'custom_data43': 'string_types',
            'custom_data44': 'string_types',
            'custom_data45': 'string_types',
            'custom_data46': 'string_types',
            'custom_data47': 'string_types',
            'custom_data48': 'string_types',
            'custom_data49': 'string_types',
            'custom_data50': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'custom_data1': 'customData1',
            'custom_data2': 'customData2',
            'custom_data3': 'customData3',
            'custom_data4': 'customData4',
            'custom_data5': 'customData5',
            'custom_data6': 'customData6',
            'custom_data7': 'customData7',
            'custom_data8': 'customData8',
            'custom_data9': 'customData9',
            'custom_data10': 'customData10',
            'custom_data11': 'customData11',
            'custom_data12': 'customData12',
            'custom_data13': 'customData13',
            'custom_data14': 'customData14',
            'custom_data15': 'customData15',
            'custom_data16': 'customData16',
            'custom_data17': 'customData17',
            'custom_data18': 'customData18',
            'custom_data19': 'customData19',
            'custom_data20': 'customData20',
            'custom_data21': 'customData21',
            'custom_data22': 'customData22',
            'custom_data23': 'customData23',
            'custom_data24': 'customData24',
            'custom_data25': 'customData25',
            'custom_data26': 'customData26',
            'custom_data27': 'customData27',
            'custom_data28': 'customData28',
            'custom_data29': 'customData29',
            'custom_data30': 'customData30',
            'custom_data31': 'customData31',
            'custom_data32': 'customData32',
            'custom_data33': 'customData33',
            'custom_data34': 'customData34',
            'custom_data35': 'customData35',
            'custom_data36': 'customData36',
            'custom_data37': 'customData37',
            'custom_data38': 'customData38',
            'custom_data39': 'customData39',
            'custom_data40': 'customData40',
            'custom_data41': 'customData41',
            'custom_data42': 'customData42',
            'custom_data43': 'customData43',
            'custom_data44': 'customData44',
            'custom_data45': 'customData45',
            'custom_data46': 'customData46',
            'custom_data47': 'customData47',
            'custom_data48': 'customData48',
            'custom_data49': 'customData49',
            'custom_data50': 'customData50'
        }
        return attributes

    @property
    def custom_data1(self):
        # type: () -> string_types
        """Gets the custom_data1 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 1

        :return: The custom_data1 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data1

    @custom_data1.setter
    def custom_data1(self, custom_data1):
        # type: (string_types) -> None
        """Sets the custom_data1 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 1

        :param custom_data1: The custom_data1 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data1 is not None:
            if custom_data1 is not None and len(custom_data1) > 100:
                raise ValueError("Invalid value for `custom_data1`, length must be less than or equal to `100`")
            if not isinstance(custom_data1, string_types):
                raise TypeError("Invalid type for `custom_data1`, type has to be `string_types`")

        self._custom_data1 = custom_data1

    @property
    def custom_data2(self):
        # type: () -> string_types
        """Gets the custom_data2 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 2

        :return: The custom_data2 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data2

    @custom_data2.setter
    def custom_data2(self, custom_data2):
        # type: (string_types) -> None
        """Sets the custom_data2 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 2

        :param custom_data2: The custom_data2 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data2 is not None:
            if custom_data2 is not None and len(custom_data2) > 100:
                raise ValueError("Invalid value for `custom_data2`, length must be less than or equal to `100`")
            if not isinstance(custom_data2, string_types):
                raise TypeError("Invalid type for `custom_data2`, type has to be `string_types`")

        self._custom_data2 = custom_data2

    @property
    def custom_data3(self):
        # type: () -> string_types
        """Gets the custom_data3 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 3

        :return: The custom_data3 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data3

    @custom_data3.setter
    def custom_data3(self, custom_data3):
        # type: (string_types) -> None
        """Sets the custom_data3 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 3

        :param custom_data3: The custom_data3 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data3 is not None:
            if custom_data3 is not None and len(custom_data3) > 100:
                raise ValueError("Invalid value for `custom_data3`, length must be less than or equal to `100`")
            if not isinstance(custom_data3, string_types):
                raise TypeError("Invalid type for `custom_data3`, type has to be `string_types`")

        self._custom_data3 = custom_data3

    @property
    def custom_data4(self):
        # type: () -> string_types
        """Gets the custom_data4 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 4

        :return: The custom_data4 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data4

    @custom_data4.setter
    def custom_data4(self, custom_data4):
        # type: (string_types) -> None
        """Sets the custom_data4 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 4

        :param custom_data4: The custom_data4 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data4 is not None:
            if custom_data4 is not None and len(custom_data4) > 100:
                raise ValueError("Invalid value for `custom_data4`, length must be less than or equal to `100`")
            if not isinstance(custom_data4, string_types):
                raise TypeError("Invalid type for `custom_data4`, type has to be `string_types`")

        self._custom_data4 = custom_data4

    @property
    def custom_data5(self):
        # type: () -> string_types
        """Gets the custom_data5 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 5

        :return: The custom_data5 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data5

    @custom_data5.setter
    def custom_data5(self, custom_data5):
        # type: (string_types) -> None
        """Sets the custom_data5 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 5

        :param custom_data5: The custom_data5 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data5 is not None:
            if custom_data5 is not None and len(custom_data5) > 100:
                raise ValueError("Invalid value for `custom_data5`, length must be less than or equal to `100`")
            if not isinstance(custom_data5, string_types):
                raise TypeError("Invalid type for `custom_data5`, type has to be `string_types`")

        self._custom_data5 = custom_data5

    @property
    def custom_data6(self):
        # type: () -> string_types
        """Gets the custom_data6 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 6

        :return: The custom_data6 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data6

    @custom_data6.setter
    def custom_data6(self, custom_data6):
        # type: (string_types) -> None
        """Sets the custom_data6 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 6

        :param custom_data6: The custom_data6 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data6 is not None:
            if custom_data6 is not None and len(custom_data6) > 100:
                raise ValueError("Invalid value for `custom_data6`, length must be less than or equal to `100`")
            if not isinstance(custom_data6, string_types):
                raise TypeError("Invalid type for `custom_data6`, type has to be `string_types`")

        self._custom_data6 = custom_data6

    @property
    def custom_data7(self):
        # type: () -> string_types
        """Gets the custom_data7 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 7

        :return: The custom_data7 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data7

    @custom_data7.setter
    def custom_data7(self, custom_data7):
        # type: (string_types) -> None
        """Sets the custom_data7 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 7

        :param custom_data7: The custom_data7 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data7 is not None:
            if custom_data7 is not None and len(custom_data7) > 100:
                raise ValueError("Invalid value for `custom_data7`, length must be less than or equal to `100`")
            if not isinstance(custom_data7, string_types):
                raise TypeError("Invalid type for `custom_data7`, type has to be `string_types`")

        self._custom_data7 = custom_data7

    @property
    def custom_data8(self):
        # type: () -> string_types
        """Gets the custom_data8 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 8

        :return: The custom_data8 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data8

    @custom_data8.setter
    def custom_data8(self, custom_data8):
        # type: (string_types) -> None
        """Sets the custom_data8 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 8

        :param custom_data8: The custom_data8 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data8 is not None:
            if custom_data8 is not None and len(custom_data8) > 100:
                raise ValueError("Invalid value for `custom_data8`, length must be less than or equal to `100`")
            if not isinstance(custom_data8, string_types):
                raise TypeError("Invalid type for `custom_data8`, type has to be `string_types`")

        self._custom_data8 = custom_data8

    @property
    def custom_data9(self):
        # type: () -> string_types
        """Gets the custom_data9 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 9

        :return: The custom_data9 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data9

    @custom_data9.setter
    def custom_data9(self, custom_data9):
        # type: (string_types) -> None
        """Sets the custom_data9 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 9

        :param custom_data9: The custom_data9 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data9 is not None:
            if custom_data9 is not None and len(custom_data9) > 100:
                raise ValueError("Invalid value for `custom_data9`, length must be less than or equal to `100`")
            if not isinstance(custom_data9, string_types):
                raise TypeError("Invalid type for `custom_data9`, type has to be `string_types`")

        self._custom_data9 = custom_data9

    @property
    def custom_data10(self):
        # type: () -> string_types
        """Gets the custom_data10 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 10

        :return: The custom_data10 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data10

    @custom_data10.setter
    def custom_data10(self, custom_data10):
        # type: (string_types) -> None
        """Sets the custom_data10 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 10

        :param custom_data10: The custom_data10 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data10 is not None:
            if custom_data10 is not None and len(custom_data10) > 100:
                raise ValueError("Invalid value for `custom_data10`, length must be less than or equal to `100`")
            if not isinstance(custom_data10, string_types):
                raise TypeError("Invalid type for `custom_data10`, type has to be `string_types`")

        self._custom_data10 = custom_data10

    @property
    def custom_data11(self):
        # type: () -> string_types
        """Gets the custom_data11 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 11

        :return: The custom_data11 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data11

    @custom_data11.setter
    def custom_data11(self, custom_data11):
        # type: (string_types) -> None
        """Sets the custom_data11 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 11

        :param custom_data11: The custom_data11 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data11 is not None:
            if custom_data11 is not None and len(custom_data11) > 100:
                raise ValueError("Invalid value for `custom_data11`, length must be less than or equal to `100`")
            if not isinstance(custom_data11, string_types):
                raise TypeError("Invalid type for `custom_data11`, type has to be `string_types`")

        self._custom_data11 = custom_data11

    @property
    def custom_data12(self):
        # type: () -> string_types
        """Gets the custom_data12 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 12

        :return: The custom_data12 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data12

    @custom_data12.setter
    def custom_data12(self, custom_data12):
        # type: (string_types) -> None
        """Sets the custom_data12 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 12

        :param custom_data12: The custom_data12 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data12 is not None:
            if custom_data12 is not None and len(custom_data12) > 100:
                raise ValueError("Invalid value for `custom_data12`, length must be less than or equal to `100`")
            if not isinstance(custom_data12, string_types):
                raise TypeError("Invalid type for `custom_data12`, type has to be `string_types`")

        self._custom_data12 = custom_data12

    @property
    def custom_data13(self):
        # type: () -> string_types
        """Gets the custom_data13 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 13

        :return: The custom_data13 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data13

    @custom_data13.setter
    def custom_data13(self, custom_data13):
        # type: (string_types) -> None
        """Sets the custom_data13 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 13

        :param custom_data13: The custom_data13 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data13 is not None:
            if custom_data13 is not None and len(custom_data13) > 100:
                raise ValueError("Invalid value for `custom_data13`, length must be less than or equal to `100`")
            if not isinstance(custom_data13, string_types):
                raise TypeError("Invalid type for `custom_data13`, type has to be `string_types`")

        self._custom_data13 = custom_data13

    @property
    def custom_data14(self):
        # type: () -> string_types
        """Gets the custom_data14 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 14

        :return: The custom_data14 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data14

    @custom_data14.setter
    def custom_data14(self, custom_data14):
        # type: (string_types) -> None
        """Sets the custom_data14 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 14

        :param custom_data14: The custom_data14 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data14 is not None:
            if custom_data14 is not None and len(custom_data14) > 100:
                raise ValueError("Invalid value for `custom_data14`, length must be less than or equal to `100`")
            if not isinstance(custom_data14, string_types):
                raise TypeError("Invalid type for `custom_data14`, type has to be `string_types`")

        self._custom_data14 = custom_data14

    @property
    def custom_data15(self):
        # type: () -> string_types
        """Gets the custom_data15 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 15

        :return: The custom_data15 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data15

    @custom_data15.setter
    def custom_data15(self, custom_data15):
        # type: (string_types) -> None
        """Sets the custom_data15 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 15

        :param custom_data15: The custom_data15 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data15 is not None:
            if custom_data15 is not None and len(custom_data15) > 100:
                raise ValueError("Invalid value for `custom_data15`, length must be less than or equal to `100`")
            if not isinstance(custom_data15, string_types):
                raise TypeError("Invalid type for `custom_data15`, type has to be `string_types`")

        self._custom_data15 = custom_data15

    @property
    def custom_data16(self):
        # type: () -> string_types
        """Gets the custom_data16 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 16

        :return: The custom_data16 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data16

    @custom_data16.setter
    def custom_data16(self, custom_data16):
        # type: (string_types) -> None
        """Sets the custom_data16 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 16

        :param custom_data16: The custom_data16 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data16 is not None:
            if custom_data16 is not None and len(custom_data16) > 100:
                raise ValueError("Invalid value for `custom_data16`, length must be less than or equal to `100`")
            if not isinstance(custom_data16, string_types):
                raise TypeError("Invalid type for `custom_data16`, type has to be `string_types`")

        self._custom_data16 = custom_data16

    @property
    def custom_data17(self):
        # type: () -> string_types
        """Gets the custom_data17 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 17

        :return: The custom_data17 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data17

    @custom_data17.setter
    def custom_data17(self, custom_data17):
        # type: (string_types) -> None
        """Sets the custom_data17 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 17

        :param custom_data17: The custom_data17 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data17 is not None:
            if custom_data17 is not None and len(custom_data17) > 100:
                raise ValueError("Invalid value for `custom_data17`, length must be less than or equal to `100`")
            if not isinstance(custom_data17, string_types):
                raise TypeError("Invalid type for `custom_data17`, type has to be `string_types`")

        self._custom_data17 = custom_data17

    @property
    def custom_data18(self):
        # type: () -> string_types
        """Gets the custom_data18 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 18

        :return: The custom_data18 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data18

    @custom_data18.setter
    def custom_data18(self, custom_data18):
        # type: (string_types) -> None
        """Sets the custom_data18 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 18

        :param custom_data18: The custom_data18 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data18 is not None:
            if custom_data18 is not None and len(custom_data18) > 100:
                raise ValueError("Invalid value for `custom_data18`, length must be less than or equal to `100`")
            if not isinstance(custom_data18, string_types):
                raise TypeError("Invalid type for `custom_data18`, type has to be `string_types`")

        self._custom_data18 = custom_data18

    @property
    def custom_data19(self):
        # type: () -> string_types
        """Gets the custom_data19 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 19

        :return: The custom_data19 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data19

    @custom_data19.setter
    def custom_data19(self, custom_data19):
        # type: (string_types) -> None
        """Sets the custom_data19 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 19

        :param custom_data19: The custom_data19 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data19 is not None:
            if custom_data19 is not None and len(custom_data19) > 100:
                raise ValueError("Invalid value for `custom_data19`, length must be less than or equal to `100`")
            if not isinstance(custom_data19, string_types):
                raise TypeError("Invalid type for `custom_data19`, type has to be `string_types`")

        self._custom_data19 = custom_data19

    @property
    def custom_data20(self):
        # type: () -> string_types
        """Gets the custom_data20 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 20

        :return: The custom_data20 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data20

    @custom_data20.setter
    def custom_data20(self, custom_data20):
        # type: (string_types) -> None
        """Sets the custom_data20 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 20

        :param custom_data20: The custom_data20 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data20 is not None:
            if custom_data20 is not None and len(custom_data20) > 100:
                raise ValueError("Invalid value for `custom_data20`, length must be less than or equal to `100`")
            if not isinstance(custom_data20, string_types):
                raise TypeError("Invalid type for `custom_data20`, type has to be `string_types`")

        self._custom_data20 = custom_data20

    @property
    def custom_data21(self):
        # type: () -> string_types
        """Gets the custom_data21 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 21

        :return: The custom_data21 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data21

    @custom_data21.setter
    def custom_data21(self, custom_data21):
        # type: (string_types) -> None
        """Sets the custom_data21 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 21

        :param custom_data21: The custom_data21 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data21 is not None:
            if custom_data21 is not None and len(custom_data21) > 100:
                raise ValueError("Invalid value for `custom_data21`, length must be less than or equal to `100`")
            if not isinstance(custom_data21, string_types):
                raise TypeError("Invalid type for `custom_data21`, type has to be `string_types`")

        self._custom_data21 = custom_data21

    @property
    def custom_data22(self):
        # type: () -> string_types
        """Gets the custom_data22 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 22

        :return: The custom_data22 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data22

    @custom_data22.setter
    def custom_data22(self, custom_data22):
        # type: (string_types) -> None
        """Sets the custom_data22 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 22

        :param custom_data22: The custom_data22 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data22 is not None:
            if custom_data22 is not None and len(custom_data22) > 100:
                raise ValueError("Invalid value for `custom_data22`, length must be less than or equal to `100`")
            if not isinstance(custom_data22, string_types):
                raise TypeError("Invalid type for `custom_data22`, type has to be `string_types`")

        self._custom_data22 = custom_data22

    @property
    def custom_data23(self):
        # type: () -> string_types
        """Gets the custom_data23 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 23

        :return: The custom_data23 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data23

    @custom_data23.setter
    def custom_data23(self, custom_data23):
        # type: (string_types) -> None
        """Sets the custom_data23 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 23

        :param custom_data23: The custom_data23 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data23 is not None:
            if custom_data23 is not None and len(custom_data23) > 100:
                raise ValueError("Invalid value for `custom_data23`, length must be less than or equal to `100`")
            if not isinstance(custom_data23, string_types):
                raise TypeError("Invalid type for `custom_data23`, type has to be `string_types`")

        self._custom_data23 = custom_data23

    @property
    def custom_data24(self):
        # type: () -> string_types
        """Gets the custom_data24 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 24

        :return: The custom_data24 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data24

    @custom_data24.setter
    def custom_data24(self, custom_data24):
        # type: (string_types) -> None
        """Sets the custom_data24 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 24

        :param custom_data24: The custom_data24 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data24 is not None:
            if custom_data24 is not None and len(custom_data24) > 100:
                raise ValueError("Invalid value for `custom_data24`, length must be less than or equal to `100`")
            if not isinstance(custom_data24, string_types):
                raise TypeError("Invalid type for `custom_data24`, type has to be `string_types`")

        self._custom_data24 = custom_data24

    @property
    def custom_data25(self):
        # type: () -> string_types
        """Gets the custom_data25 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 25

        :return: The custom_data25 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data25

    @custom_data25.setter
    def custom_data25(self, custom_data25):
        # type: (string_types) -> None
        """Sets the custom_data25 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 25

        :param custom_data25: The custom_data25 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data25 is not None:
            if custom_data25 is not None and len(custom_data25) > 100:
                raise ValueError("Invalid value for `custom_data25`, length must be less than or equal to `100`")
            if not isinstance(custom_data25, string_types):
                raise TypeError("Invalid type for `custom_data25`, type has to be `string_types`")

        self._custom_data25 = custom_data25

    @property
    def custom_data26(self):
        # type: () -> string_types
        """Gets the custom_data26 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 26

        :return: The custom_data26 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data26

    @custom_data26.setter
    def custom_data26(self, custom_data26):
        # type: (string_types) -> None
        """Sets the custom_data26 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 26

        :param custom_data26: The custom_data26 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data26 is not None:
            if custom_data26 is not None and len(custom_data26) > 100:
                raise ValueError("Invalid value for `custom_data26`, length must be less than or equal to `100`")
            if not isinstance(custom_data26, string_types):
                raise TypeError("Invalid type for `custom_data26`, type has to be `string_types`")

        self._custom_data26 = custom_data26

    @property
    def custom_data27(self):
        # type: () -> string_types
        """Gets the custom_data27 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 27

        :return: The custom_data27 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data27

    @custom_data27.setter
    def custom_data27(self, custom_data27):
        # type: (string_types) -> None
        """Sets the custom_data27 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 27

        :param custom_data27: The custom_data27 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data27 is not None:
            if custom_data27 is not None and len(custom_data27) > 100:
                raise ValueError("Invalid value for `custom_data27`, length must be less than or equal to `100`")
            if not isinstance(custom_data27, string_types):
                raise TypeError("Invalid type for `custom_data27`, type has to be `string_types`")

        self._custom_data27 = custom_data27

    @property
    def custom_data28(self):
        # type: () -> string_types
        """Gets the custom_data28 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 28

        :return: The custom_data28 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data28

    @custom_data28.setter
    def custom_data28(self, custom_data28):
        # type: (string_types) -> None
        """Sets the custom_data28 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 28

        :param custom_data28: The custom_data28 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data28 is not None:
            if custom_data28 is not None and len(custom_data28) > 100:
                raise ValueError("Invalid value for `custom_data28`, length must be less than or equal to `100`")
            if not isinstance(custom_data28, string_types):
                raise TypeError("Invalid type for `custom_data28`, type has to be `string_types`")

        self._custom_data28 = custom_data28

    @property
    def custom_data29(self):
        # type: () -> string_types
        """Gets the custom_data29 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 29

        :return: The custom_data29 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data29

    @custom_data29.setter
    def custom_data29(self, custom_data29):
        # type: (string_types) -> None
        """Sets the custom_data29 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 29

        :param custom_data29: The custom_data29 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data29 is not None:
            if custom_data29 is not None and len(custom_data29) > 100:
                raise ValueError("Invalid value for `custom_data29`, length must be less than or equal to `100`")
            if not isinstance(custom_data29, string_types):
                raise TypeError("Invalid type for `custom_data29`, type has to be `string_types`")

        self._custom_data29 = custom_data29

    @property
    def custom_data30(self):
        # type: () -> string_types
        """Gets the custom_data30 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 30

        :return: The custom_data30 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data30

    @custom_data30.setter
    def custom_data30(self, custom_data30):
        # type: (string_types) -> None
        """Sets the custom_data30 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 30

        :param custom_data30: The custom_data30 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data30 is not None:
            if custom_data30 is not None and len(custom_data30) > 100:
                raise ValueError("Invalid value for `custom_data30`, length must be less than or equal to `100`")
            if not isinstance(custom_data30, string_types):
                raise TypeError("Invalid type for `custom_data30`, type has to be `string_types`")

        self._custom_data30 = custom_data30

    @property
    def custom_data31(self):
        # type: () -> string_types
        """Gets the custom_data31 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 31

        :return: The custom_data31 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data31

    @custom_data31.setter
    def custom_data31(self, custom_data31):
        # type: (string_types) -> None
        """Sets the custom_data31 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 31

        :param custom_data31: The custom_data31 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data31 is not None:
            if custom_data31 is not None and len(custom_data31) > 100:
                raise ValueError("Invalid value for `custom_data31`, length must be less than or equal to `100`")
            if not isinstance(custom_data31, string_types):
                raise TypeError("Invalid type for `custom_data31`, type has to be `string_types`")

        self._custom_data31 = custom_data31

    @property
    def custom_data32(self):
        # type: () -> string_types
        """Gets the custom_data32 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 32

        :return: The custom_data32 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data32

    @custom_data32.setter
    def custom_data32(self, custom_data32):
        # type: (string_types) -> None
        """Sets the custom_data32 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 32

        :param custom_data32: The custom_data32 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data32 is not None:
            if custom_data32 is not None and len(custom_data32) > 100:
                raise ValueError("Invalid value for `custom_data32`, length must be less than or equal to `100`")
            if not isinstance(custom_data32, string_types):
                raise TypeError("Invalid type for `custom_data32`, type has to be `string_types`")

        self._custom_data32 = custom_data32

    @property
    def custom_data33(self):
        # type: () -> string_types
        """Gets the custom_data33 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 33

        :return: The custom_data33 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data33

    @custom_data33.setter
    def custom_data33(self, custom_data33):
        # type: (string_types) -> None
        """Sets the custom_data33 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 33

        :param custom_data33: The custom_data33 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data33 is not None:
            if custom_data33 is not None and len(custom_data33) > 100:
                raise ValueError("Invalid value for `custom_data33`, length must be less than or equal to `100`")
            if not isinstance(custom_data33, string_types):
                raise TypeError("Invalid type for `custom_data33`, type has to be `string_types`")

        self._custom_data33 = custom_data33

    @property
    def custom_data34(self):
        # type: () -> string_types
        """Gets the custom_data34 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 34

        :return: The custom_data34 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data34

    @custom_data34.setter
    def custom_data34(self, custom_data34):
        # type: (string_types) -> None
        """Sets the custom_data34 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 34

        :param custom_data34: The custom_data34 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data34 is not None:
            if custom_data34 is not None and len(custom_data34) > 100:
                raise ValueError("Invalid value for `custom_data34`, length must be less than or equal to `100`")
            if not isinstance(custom_data34, string_types):
                raise TypeError("Invalid type for `custom_data34`, type has to be `string_types`")

        self._custom_data34 = custom_data34

    @property
    def custom_data35(self):
        # type: () -> string_types
        """Gets the custom_data35 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 35

        :return: The custom_data35 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data35

    @custom_data35.setter
    def custom_data35(self, custom_data35):
        # type: (string_types) -> None
        """Sets the custom_data35 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 35

        :param custom_data35: The custom_data35 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data35 is not None:
            if custom_data35 is not None and len(custom_data35) > 100:
                raise ValueError("Invalid value for `custom_data35`, length must be less than or equal to `100`")
            if not isinstance(custom_data35, string_types):
                raise TypeError("Invalid type for `custom_data35`, type has to be `string_types`")

        self._custom_data35 = custom_data35

    @property
    def custom_data36(self):
        # type: () -> string_types
        """Gets the custom_data36 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 36

        :return: The custom_data36 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data36

    @custom_data36.setter
    def custom_data36(self, custom_data36):
        # type: (string_types) -> None
        """Sets the custom_data36 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 36

        :param custom_data36: The custom_data36 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data36 is not None:
            if custom_data36 is not None and len(custom_data36) > 100:
                raise ValueError("Invalid value for `custom_data36`, length must be less than or equal to `100`")
            if not isinstance(custom_data36, string_types):
                raise TypeError("Invalid type for `custom_data36`, type has to be `string_types`")

        self._custom_data36 = custom_data36

    @property
    def custom_data37(self):
        # type: () -> string_types
        """Gets the custom_data37 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 37

        :return: The custom_data37 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data37

    @custom_data37.setter
    def custom_data37(self, custom_data37):
        # type: (string_types) -> None
        """Sets the custom_data37 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 37

        :param custom_data37: The custom_data37 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data37 is not None:
            if custom_data37 is not None and len(custom_data37) > 100:
                raise ValueError("Invalid value for `custom_data37`, length must be less than or equal to `100`")
            if not isinstance(custom_data37, string_types):
                raise TypeError("Invalid type for `custom_data37`, type has to be `string_types`")

        self._custom_data37 = custom_data37

    @property
    def custom_data38(self):
        # type: () -> string_types
        """Gets the custom_data38 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 38

        :return: The custom_data38 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data38

    @custom_data38.setter
    def custom_data38(self, custom_data38):
        # type: (string_types) -> None
        """Sets the custom_data38 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 38

        :param custom_data38: The custom_data38 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data38 is not None:
            if custom_data38 is not None and len(custom_data38) > 100:
                raise ValueError("Invalid value for `custom_data38`, length must be less than or equal to `100`")
            if not isinstance(custom_data38, string_types):
                raise TypeError("Invalid type for `custom_data38`, type has to be `string_types`")

        self._custom_data38 = custom_data38

    @property
    def custom_data39(self):
        # type: () -> string_types
        """Gets the custom_data39 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 39

        :return: The custom_data39 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data39

    @custom_data39.setter
    def custom_data39(self, custom_data39):
        # type: (string_types) -> None
        """Sets the custom_data39 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 39

        :param custom_data39: The custom_data39 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data39 is not None:
            if custom_data39 is not None and len(custom_data39) > 100:
                raise ValueError("Invalid value for `custom_data39`, length must be less than or equal to `100`")
            if not isinstance(custom_data39, string_types):
                raise TypeError("Invalid type for `custom_data39`, type has to be `string_types`")

        self._custom_data39 = custom_data39

    @property
    def custom_data40(self):
        # type: () -> string_types
        """Gets the custom_data40 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 40

        :return: The custom_data40 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data40

    @custom_data40.setter
    def custom_data40(self, custom_data40):
        # type: (string_types) -> None
        """Sets the custom_data40 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 40

        :param custom_data40: The custom_data40 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data40 is not None:
            if custom_data40 is not None and len(custom_data40) > 100:
                raise ValueError("Invalid value for `custom_data40`, length must be less than or equal to `100`")
            if not isinstance(custom_data40, string_types):
                raise TypeError("Invalid type for `custom_data40`, type has to be `string_types`")

        self._custom_data40 = custom_data40

    @property
    def custom_data41(self):
        # type: () -> string_types
        """Gets the custom_data41 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 41

        :return: The custom_data41 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data41

    @custom_data41.setter
    def custom_data41(self, custom_data41):
        # type: (string_types) -> None
        """Sets the custom_data41 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 41

        :param custom_data41: The custom_data41 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data41 is not None:
            if custom_data41 is not None and len(custom_data41) > 100:
                raise ValueError("Invalid value for `custom_data41`, length must be less than or equal to `100`")
            if not isinstance(custom_data41, string_types):
                raise TypeError("Invalid type for `custom_data41`, type has to be `string_types`")

        self._custom_data41 = custom_data41

    @property
    def custom_data42(self):
        # type: () -> string_types
        """Gets the custom_data42 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 42

        :return: The custom_data42 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data42

    @custom_data42.setter
    def custom_data42(self, custom_data42):
        # type: (string_types) -> None
        """Sets the custom_data42 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 42

        :param custom_data42: The custom_data42 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data42 is not None:
            if custom_data42 is not None and len(custom_data42) > 100:
                raise ValueError("Invalid value for `custom_data42`, length must be less than or equal to `100`")
            if not isinstance(custom_data42, string_types):
                raise TypeError("Invalid type for `custom_data42`, type has to be `string_types`")

        self._custom_data42 = custom_data42

    @property
    def custom_data43(self):
        # type: () -> string_types
        """Gets the custom_data43 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 43

        :return: The custom_data43 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data43

    @custom_data43.setter
    def custom_data43(self, custom_data43):
        # type: (string_types) -> None
        """Sets the custom_data43 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 43

        :param custom_data43: The custom_data43 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data43 is not None:
            if custom_data43 is not None and len(custom_data43) > 100:
                raise ValueError("Invalid value for `custom_data43`, length must be less than or equal to `100`")
            if not isinstance(custom_data43, string_types):
                raise TypeError("Invalid type for `custom_data43`, type has to be `string_types`")

        self._custom_data43 = custom_data43

    @property
    def custom_data44(self):
        # type: () -> string_types
        """Gets the custom_data44 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 44

        :return: The custom_data44 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data44

    @custom_data44.setter
    def custom_data44(self, custom_data44):
        # type: (string_types) -> None
        """Sets the custom_data44 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 44

        :param custom_data44: The custom_data44 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data44 is not None:
            if custom_data44 is not None and len(custom_data44) > 100:
                raise ValueError("Invalid value for `custom_data44`, length must be less than or equal to `100`")
            if not isinstance(custom_data44, string_types):
                raise TypeError("Invalid type for `custom_data44`, type has to be `string_types`")

        self._custom_data44 = custom_data44

    @property
    def custom_data45(self):
        # type: () -> string_types
        """Gets the custom_data45 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 45

        :return: The custom_data45 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data45

    @custom_data45.setter
    def custom_data45(self, custom_data45):
        # type: (string_types) -> None
        """Sets the custom_data45 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 45

        :param custom_data45: The custom_data45 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data45 is not None:
            if custom_data45 is not None and len(custom_data45) > 100:
                raise ValueError("Invalid value for `custom_data45`, length must be less than or equal to `100`")
            if not isinstance(custom_data45, string_types):
                raise TypeError("Invalid type for `custom_data45`, type has to be `string_types`")

        self._custom_data45 = custom_data45

    @property
    def custom_data46(self):
        # type: () -> string_types
        """Gets the custom_data46 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 46

        :return: The custom_data46 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data46

    @custom_data46.setter
    def custom_data46(self, custom_data46):
        # type: (string_types) -> None
        """Sets the custom_data46 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 46

        :param custom_data46: The custom_data46 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data46 is not None:
            if custom_data46 is not None and len(custom_data46) > 100:
                raise ValueError("Invalid value for `custom_data46`, length must be less than or equal to `100`")
            if not isinstance(custom_data46, string_types):
                raise TypeError("Invalid type for `custom_data46`, type has to be `string_types`")

        self._custom_data46 = custom_data46

    @property
    def custom_data47(self):
        # type: () -> string_types
        """Gets the custom_data47 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 47

        :return: The custom_data47 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data47

    @custom_data47.setter
    def custom_data47(self, custom_data47):
        # type: (string_types) -> None
        """Sets the custom_data47 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 47

        :param custom_data47: The custom_data47 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data47 is not None:
            if custom_data47 is not None and len(custom_data47) > 100:
                raise ValueError("Invalid value for `custom_data47`, length must be less than or equal to `100`")
            if not isinstance(custom_data47, string_types):
                raise TypeError("Invalid type for `custom_data47`, type has to be `string_types`")

        self._custom_data47 = custom_data47

    @property
    def custom_data48(self):
        # type: () -> string_types
        """Gets the custom_data48 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 48

        :return: The custom_data48 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data48

    @custom_data48.setter
    def custom_data48(self, custom_data48):
        # type: (string_types) -> None
        """Sets the custom_data48 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 48

        :param custom_data48: The custom_data48 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data48 is not None:
            if custom_data48 is not None and len(custom_data48) > 100:
                raise ValueError("Invalid value for `custom_data48`, length must be less than or equal to `100`")
            if not isinstance(custom_data48, string_types):
                raise TypeError("Invalid type for `custom_data48`, type has to be `string_types`")

        self._custom_data48 = custom_data48

    @property
    def custom_data49(self):
        # type: () -> string_types
        """Gets the custom_data49 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 49

        :return: The custom_data49 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data49

    @custom_data49.setter
    def custom_data49(self, custom_data49):
        # type: (string_types) -> None
        """Sets the custom_data49 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 49

        :param custom_data49: The custom_data49 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data49 is not None:
            if custom_data49 is not None and len(custom_data49) > 100:
                raise ValueError("Invalid value for `custom_data49`, length must be less than or equal to `100`")
            if not isinstance(custom_data49, string_types):
                raise TypeError("Invalid type for `custom_data49`, type has to be `string_types`")

        self._custom_data49 = custom_data49

    @property
    def custom_data50(self):
        # type: () -> string_types
        """Gets the custom_data50 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 50

        :return: The custom_data50 of this AnalyticsLicenseCustomDataFieldLabels.
        :rtype: string_types
        """
        return self._custom_data50

    @custom_data50.setter
    def custom_data50(self, custom_data50):
        # type: (string_types) -> None
        """Sets the custom_data50 of this AnalyticsLicenseCustomDataFieldLabels.

        Label for field Custom Data 50

        :param custom_data50: The custom_data50 of this AnalyticsLicenseCustomDataFieldLabels.
        :type: string_types
        """

        if custom_data50 is not None:
            if custom_data50 is not None and len(custom_data50) > 100:
                raise ValueError("Invalid value for `custom_data50`, length must be less than or equal to `100`")
            if not isinstance(custom_data50, string_types):
                raise TypeError("Invalid type for `custom_data50`, type has to be `string_types`")

        self._custom_data50 = custom_data50

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsLicenseCustomDataFieldLabels):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.convert_scc_caption_web_vtt_settings import ConvertSccCaptionWebVttSettings
from bitmovin_api_sdk.models.input_path import InputPath
from bitmovin_api_sdk.models.stream_caption_output_format import StreamCaptionOutputFormat
import pprint
import six


class ConvertSccCaption(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 input_=None,
                 outputs=None,
                 file_name=None,
                 output_format=None,
                 web_vtt_settings=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, InputPath, list[EncodingOutput], string_types, StreamCaptionOutputFormat, ConvertSccCaptionWebVttSettings) -> None
        super(ConvertSccCaption, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._input = None
        self._outputs = list()
        self._file_name = None
        self._output_format = None
        self._web_vtt_settings = None
        self.discriminator = None

        if input_ is not None:
            self.input = input_
        if outputs is not None:
            self.outputs = outputs
        if file_name is not None:
            self.file_name = file_name
        if output_format is not None:
            self.output_format = output_format
        if web_vtt_settings is not None:
            self.web_vtt_settings = web_vtt_settings

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(ConvertSccCaption, self), 'openapi_types'):
            types = getattr(super(ConvertSccCaption, self), 'openapi_types')

        types.update({
            'input': 'InputPath',
            'outputs': 'list[EncodingOutput]',
            'file_name': 'string_types',
            'output_format': 'StreamCaptionOutputFormat',
            'web_vtt_settings': 'ConvertSccCaptionWebVttSettings'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(ConvertSccCaption, self), 'attribute_map'):
            attributes = getattr(super(ConvertSccCaption, self), 'attribute_map')

        attributes.update({
            'input': 'input',
            'outputs': 'outputs',
            'file_name': 'fileName',
            'output_format': 'outputFormat',
            'web_vtt_settings': 'webVttSettings'
        })
        return attributes

    @property
    def input(self):
        # type: () -> InputPath
        """Gets the input of this ConvertSccCaption.

        The input location to get the scc file from (required)

        :return: The input of this ConvertSccCaption.
        :rtype: InputPath
        """
        return self._input

    @input.setter
    def input(self, input_):
        # type: (InputPath) -> None
        """Sets the input of this ConvertSccCaption.

        The input location to get the scc file from (required)

        :param input_: The input of this ConvertSccCaption.
        :type: InputPath
        """

        if input_ is not None:
            if not isinstance(input_, InputPath):
                raise TypeError("Invalid type for `input`, type has to be `InputPath`")

        self._input = input_

    @property
    def outputs(self):
        # type: () -> list[EncodingOutput]
        """Gets the outputs of this ConvertSccCaption.


        :return: The outputs of this ConvertSccCaption.
        :rtype: list[EncodingOutput]
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        # type: (list) -> None
        """Sets the outputs of this ConvertSccCaption.


        :param outputs: The outputs of this ConvertSccCaption.
        :type: list[EncodingOutput]
        """

        if outputs is not None:
            if not isinstance(outputs, list):
                raise TypeError("Invalid type for `outputs`, type has to be `list[EncodingOutput]`")

        self._outputs = outputs

    @property
    def file_name(self):
        # type: () -> string_types
        """Gets the file_name of this ConvertSccCaption.

        Name of the captions file (required)

        :return: The file_name of this ConvertSccCaption.
        :rtype: string_types
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        # type: (string_types) -> None
        """Sets the file_name of this ConvertSccCaption.

        Name of the captions file (required)

        :param file_name: The file_name of this ConvertSccCaption.
        :type: string_types
        """

        if file_name is not None:
            if not isinstance(file_name, string_types):
                raise TypeError("Invalid type for `file_name`, type has to be `string_types`")

        self._file_name = file_name

    @property
    def output_format(self):
        # type: () -> StreamCaptionOutputFormat
        """Gets the output_format of this ConvertSccCaption.


        :return: The output_format of this ConvertSccCaption.
        :rtype: StreamCaptionOutputFormat
        """
        return self._output_format

    @output_format.setter
    def output_format(self, output_format):
        # type: (StreamCaptionOutputFormat) -> None
        """Sets the output_format of this ConvertSccCaption.


        :param output_format: The output_format of this ConvertSccCaption.
        :type: StreamCaptionOutputFormat
        """

        if output_format is not None:
            if not isinstance(output_format, StreamCaptionOutputFormat):
                raise TypeError("Invalid type for `output_format`, type has to be `StreamCaptionOutputFormat`")

        self._output_format = output_format

    @property
    def web_vtt_settings(self):
        # type: () -> ConvertSccCaptionWebVttSettings
        """Gets the web_vtt_settings of this ConvertSccCaption.

        Optional settings when converting SCC to WebVTT

        :return: The web_vtt_settings of this ConvertSccCaption.
        :rtype: ConvertSccCaptionWebVttSettings
        """
        return self._web_vtt_settings

    @web_vtt_settings.setter
    def web_vtt_settings(self, web_vtt_settings):
        # type: (ConvertSccCaptionWebVttSettings) -> None
        """Sets the web_vtt_settings of this ConvertSccCaption.

        Optional settings when converting SCC to WebVTT

        :param web_vtt_settings: The web_vtt_settings of this ConvertSccCaption.
        :type: ConvertSccCaptionWebVttSettings
        """

        if web_vtt_settings is not None:
            if not isinstance(web_vtt_settings, ConvertSccCaptionWebVttSettings):
                raise TypeError("Invalid type for `web_vtt_settings`, type has to be `ConvertSccCaptionWebVttSettings`")

        self._web_vtt_settings = web_vtt_settings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(ConvertSccCaption, self), "to_dict"):
            result = super(ConvertSccCaption, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConvertSccCaption):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.encodings.muxings.ts.drm.fairplay.fairplay_api import FairplayApi
from bitmovin_api_sdk.encoding.encodings.muxings.ts.drm.fairplay.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.ts.drm.fairplay.fair_play_drm_list_query_params import FairPlayDrmListQueryParams



from bitmovin_api_sdk.encoding.configurations.audio.dts.dts_api import DtsApi
from bitmovin_api_sdk.encoding.configurations.audio.dts.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.audio.dts.dts_audio_configuration_list_query_params import DtsAudioConfigurationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.cloud_region import CloudRegion
from bitmovin_api_sdk.models.prewarmed_encoder_disk_size import PrewarmedEncoderDiskSize
from bitmovin_api_sdk.models.prewarmed_encoder_pool_status import PrewarmedEncoderPoolStatus
import pprint
import six


class PrewarmedEncoderPool(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 encoder_version=None,
                 cloud_region=None,
                 infrastructure_id=None,
                 disk_size=None,
                 target_pool_size=None,
                 dynamic_pool=None,
                 gpu_enabled=None,
                 status=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, CloudRegion, string_types, PrewarmedEncoderDiskSize, int, bool, bool, PrewarmedEncoderPoolStatus) -> None
        super(PrewarmedEncoderPool, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._encoder_version = None
        self._cloud_region = None
        self._infrastructure_id = None
        self._disk_size = None
        self._target_pool_size = None
        self._dynamic_pool = None
        self._gpu_enabled = None
        self._status = None
        self.discriminator = None

        if encoder_version is not None:
            self.encoder_version = encoder_version
        if cloud_region is not None:
            self.cloud_region = cloud_region
        if infrastructure_id is not None:
            self.infrastructure_id = infrastructure_id
        if disk_size is not None:
            self.disk_size = disk_size
        if target_pool_size is not None:
            self.target_pool_size = target_pool_size
        if dynamic_pool is not None:
            self.dynamic_pool = dynamic_pool
        if gpu_enabled is not None:
            self.gpu_enabled = gpu_enabled
        if status is not None:
            self.status = status

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(PrewarmedEncoderPool, self), 'openapi_types'):
            types = getattr(super(PrewarmedEncoderPool, self), 'openapi_types')

        types.update({
            'encoder_version': 'string_types',
            'cloud_region': 'CloudRegion',
            'infrastructure_id': 'string_types',
            'disk_size': 'PrewarmedEncoderDiskSize',
            'target_pool_size': 'int',
            'dynamic_pool': 'bool',
            'gpu_enabled': 'bool',
            'status': 'PrewarmedEncoderPoolStatus'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(PrewarmedEncoderPool, self), 'attribute_map'):
            attributes = getattr(super(PrewarmedEncoderPool, self), 'attribute_map')

        attributes.update({
            'encoder_version': 'encoderVersion',
            'cloud_region': 'cloudRegion',
            'infrastructure_id': 'infrastructureId',
            'disk_size': 'diskSize',
            'target_pool_size': 'targetPoolSize',
            'dynamic_pool': 'dynamicPool',
            'gpu_enabled': 'gpuEnabled',
            'status': 'status'
        })
        return attributes

    @property
    def encoder_version(self):
        # type: () -> string_types
        """Gets the encoder_version of this PrewarmedEncoderPool.

        The encoder version which the pool's instances will be running (required)

        :return: The encoder_version of this PrewarmedEncoderPool.
        :rtype: string_types
        """
        return self._encoder_version

    @encoder_version.setter
    def encoder_version(self, encoder_version):
        # type: (string_types) -> None
        """Sets the encoder_version of this PrewarmedEncoderPool.

        The encoder version which the pool's instances will be running (required)

        :param encoder_version: The encoder_version of this PrewarmedEncoderPool.
        :type: string_types
        """

        if encoder_version is not None:
            if not isinstance(encoder_version, string_types):
                raise TypeError("Invalid type for `encoder_version`, type has to be `string_types`")

        self._encoder_version = encoder_version

    @property
    def cloud_region(self):
        # type: () -> CloudRegion
        """Gets the cloud_region of this PrewarmedEncoderPool.

        The cloud region in which the pool's instances will be running. Must be a specific region (e.g. not 'AUTO', 'GOOGLE' or 'EUROPE') (required)

        :return: The cloud_region of this PrewarmedEncoderPool.
        :rtype: CloudRegion
        """
        return self._cloud_region

    @cloud_region.setter
    def cloud_region(self, cloud_region):
        # type: (CloudRegion) -> None
        """Sets the cloud_region of this PrewarmedEncoderPool.

        The cloud region in which the pool's instances will be running. Must be a specific region (e.g. not 'AUTO', 'GOOGLE' or 'EUROPE') (required)

        :param cloud_region: The cloud_region of this PrewarmedEncoderPool.
        :type: CloudRegion
        """

        if cloud_region is not None:
            if not isinstance(cloud_region, CloudRegion):
                raise TypeError("Invalid type for `cloud_region`, type has to be `CloudRegion`")

        self._cloud_region = cloud_region

    @property
    def infrastructure_id(self):
        # type: () -> string_types
        """Gets the infrastructure_id of this PrewarmedEncoderPool.

        Define an external infrastructure to run the pool on.

        :return: The infrastructure_id of this PrewarmedEncoderPool.
        :rtype: string_types
        """
        return self._infrastructure_id

    @infrastructure_id.setter
    def infrastructure_id(self, infrastructure_id):
        # type: (string_types) -> None
        """Sets the infrastructure_id of this PrewarmedEncoderPool.

        Define an external infrastructure to run the pool on.

        :param infrastructure_id: The infrastructure_id of this PrewarmedEncoderPool.
        :type: string_types
        """

        if infrastructure_id is not None:
            if not isinstance(infrastructure_id, string_types):
                raise TypeError("Invalid type for `infrastructure_id`, type has to be `string_types`")

        self._infrastructure_id = infrastructure_id

    @property
    def disk_size(self):
        # type: () -> PrewarmedEncoderDiskSize
        """Gets the disk_size of this PrewarmedEncoderPool.

        Disk size of the prewarmed instances in GB. Needs to be chosen depending on input file sizes and encoding features used. (required)

        :return: The disk_size of this PrewarmedEncoderPool.
        :rtype: PrewarmedEncoderDiskSize
        """
        return self._disk_size

    @disk_size.setter
    def disk_size(self, disk_size):
        # type: (PrewarmedEncoderDiskSize) -> None
        """Sets the disk_size of this PrewarmedEncoderPool.

        Disk size of the prewarmed instances in GB. Needs to be chosen depending on input file sizes and encoding features used. (required)

        :param disk_size: The disk_size of this PrewarmedEncoderPool.
        :type: PrewarmedEncoderDiskSize
        """

        if disk_size is not None:
            if not isinstance(disk_size, PrewarmedEncoderDiskSize):
                raise TypeError("Invalid type for `disk_size`, type has to be `PrewarmedEncoderDiskSize`")

        self._disk_size = disk_size

    @property
    def target_pool_size(self):
        # type: () -> int
        """Gets the target_pool_size of this PrewarmedEncoderPool.

        Number of instances to keep prewarmed while the pool is running (required)

        :return: The target_pool_size of this PrewarmedEncoderPool.
        :rtype: int
        """
        return self._target_pool_size

    @target_pool_size.setter
    def target_pool_size(self, target_pool_size):
        # type: (int) -> None
        """Sets the target_pool_size of this PrewarmedEncoderPool.

        Number of instances to keep prewarmed while the pool is running (required)

        :param target_pool_size: The target_pool_size of this PrewarmedEncoderPool.
        :type: int
        """

        if target_pool_size is not None:
            if target_pool_size is not None and target_pool_size < 1:
                raise ValueError("Invalid value for `target_pool_size`, must be a value greater than or equal to `1`")
            if not isinstance(target_pool_size, int):
                raise TypeError("Invalid type for `target_pool_size`, type has to be `int`")

        self._target_pool_size = target_pool_size

    @property
    def dynamic_pool(self):
        # type: () -> bool
        """Gets the dynamic_pool of this PrewarmedEncoderPool.

        Activate dynamic pool behaviour. Pool will increase/decrease based on usage up until a size of 10 instances. Minimum pool size is set by targetPoolSize

        :return: The dynamic_pool of this PrewarmedEncoderPool.
        :rtype: bool
        """
        return self._dynamic_pool

    @dynamic_pool.setter
    def dynamic_pool(self, dynamic_pool):
        # type: (bool) -> None
        """Sets the dynamic_pool of this PrewarmedEncoderPool.

        Activate dynamic pool behaviour. Pool will increase/decrease based on usage up until a size of 10 instances. Minimum pool size is set by targetPoolSize

        :param dynamic_pool: The dynamic_pool of this PrewarmedEncoderPool.
        :type: bool
        """

        if dynamic_pool is not None:
            if not isinstance(dynamic_pool, bool):
                raise TypeError("Invalid type for `dynamic_pool`, type has to be `bool`")

        self._dynamic_pool = dynamic_pool

    @property
    def gpu_enabled(self):
        # type: () -> bool
        """Gets the gpu_enabled of this PrewarmedEncoderPool.

        Create pool with GPU instances for hardware encoding presets (e.g., VOD_HARDWARE_SHORTFORM).

        :return: The gpu_enabled of this PrewarmedEncoderPool.
        :rtype: bool
        """
        return self._gpu_enabled

    @gpu_enabled.setter
    def gpu_enabled(self, gpu_enabled):
        # type: (bool) -> None
        """Sets the gpu_enabled of this PrewarmedEncoderPool.

        Create pool with GPU instances for hardware encoding presets (e.g., VOD_HARDWARE_SHORTFORM).

        :param gpu_enabled: The gpu_enabled of this PrewarmedEncoderPool.
        :type: bool
        """

        if gpu_enabled is not None:
            if not isinstance(gpu_enabled, bool):
                raise TypeError("Invalid type for `gpu_enabled`, type has to be `bool`")

        self._gpu_enabled = gpu_enabled

    @property
    def status(self):
        # type: () -> PrewarmedEncoderPoolStatus
        """Gets the status of this PrewarmedEncoderPool.

        Current status of the pool.

        :return: The status of this PrewarmedEncoderPool.
        :rtype: PrewarmedEncoderPoolStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: (PrewarmedEncoderPoolStatus) -> None
        """Sets the status of this PrewarmedEncoderPool.

        Current status of the pool.

        :param status: The status of this PrewarmedEncoderPool.
        :type: PrewarmedEncoderPoolStatus
        """

        if status is not None:
            if not isinstance(status, PrewarmedEncoderPoolStatus):
                raise TypeError("Invalid type for `status`, type has to be `PrewarmedEncoderPoolStatus`")

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(PrewarmedEncoderPool, self), "to_dict"):
            result = super(PrewarmedEncoderPool, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrewarmedEncoderPool):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class AnalyticsErrorData(object):
    @poscheck_model
    def __init__(self,
                 exception_message=None,
                 additional_data=None,
                 exception_stacktrace=None):
        # type: (string_types, string_types, list[string_types]) -> None

        self._exception_message = None
        self._additional_data = None
        self._exception_stacktrace = list()
        self.discriminator = None

        if exception_message is not None:
            self.exception_message = exception_message
        if additional_data is not None:
            self.additional_data = additional_data
        if exception_stacktrace is not None:
            self.exception_stacktrace = exception_stacktrace

    @property
    def openapi_types(self):
        types = {
            'exception_message': 'string_types',
            'additional_data': 'string_types',
            'exception_stacktrace': 'list[string_types]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'exception_message': 'exceptionMessage',
            'additional_data': 'additionalData',
            'exception_stacktrace': 'exceptionStacktrace'
        }
        return attributes

    @property
    def exception_message(self):
        # type: () -> string_types
        """Gets the exception_message of this AnalyticsErrorData.

        Exception message

        :return: The exception_message of this AnalyticsErrorData.
        :rtype: string_types
        """
        return self._exception_message

    @exception_message.setter
    def exception_message(self, exception_message):
        # type: (string_types) -> None
        """Sets the exception_message of this AnalyticsErrorData.

        Exception message

        :param exception_message: The exception_message of this AnalyticsErrorData.
        :type: string_types
        """

        if exception_message is not None:
            if not isinstance(exception_message, string_types):
                raise TypeError("Invalid type for `exception_message`, type has to be `string_types`")

        self._exception_message = exception_message

    @property
    def additional_data(self):
        # type: () -> string_types
        """Gets the additional_data of this AnalyticsErrorData.

        Additional error data

        :return: The additional_data of this AnalyticsErrorData.
        :rtype: string_types
        """
        return self._additional_data

    @additional_data.setter
    def additional_data(self, additional_data):
        # type: (string_types) -> None
        """Sets the additional_data of this AnalyticsErrorData.

        Additional error data

        :param additional_data: The additional_data of this AnalyticsErrorData.
        :type: string_types
        """

        if additional_data is not None:
            if not isinstance(additional_data, string_types):
                raise TypeError("Invalid type for `additional_data`, type has to be `string_types`")

        self._additional_data = additional_data

    @property
    def exception_stacktrace(self):
        # type: () -> list[string_types]
        """Gets the exception_stacktrace of this AnalyticsErrorData.


        :return: The exception_stacktrace of this AnalyticsErrorData.
        :rtype: list[string_types]
        """
        return self._exception_stacktrace

    @exception_stacktrace.setter
    def exception_stacktrace(self, exception_stacktrace):
        # type: (list) -> None
        """Sets the exception_stacktrace of this AnalyticsErrorData.


        :param exception_stacktrace: The exception_stacktrace of this AnalyticsErrorData.
        :type: list[string_types]
        """

        if exception_stacktrace is not None:
            if not isinstance(exception_stacktrace, list):
                raise TypeError("Invalid type for `exception_stacktrace`, type has to be `list[string_types]`")

        self._exception_stacktrace = exception_stacktrace

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsErrorData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class BitrateSelectionMode(Enum):
    OPTIMIZED = "OPTIMIZED"
    COMPLEXITY_RANGE = "COMPLEXITY_RANGE"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class LiveEncoding(object):
    @poscheck_model
    def __init__(self,
                 stream_key=None,
                 encoder_ip=None,
                 application=None):
        # type: (string_types, string_types, string_types) -> None

        self._stream_key = None
        self._encoder_ip = None
        self._application = None
        self.discriminator = None

        if stream_key is not None:
            self.stream_key = stream_key
        if encoder_ip is not None:
            self.encoder_ip = encoder_ip
        if application is not None:
            self.application = application

    @property
    def openapi_types(self):
        types = {
            'stream_key': 'string_types',
            'encoder_ip': 'string_types',
            'application': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'stream_key': 'streamKey',
            'encoder_ip': 'encoderIp',
            'application': 'application'
        }
        return attributes

    @property
    def stream_key(self):
        # type: () -> string_types
        """Gets the stream_key of this LiveEncoding.

        Stream key of the live encoder (required)

        :return: The stream_key of this LiveEncoding.
        :rtype: string_types
        """
        return self._stream_key

    @stream_key.setter
    def stream_key(self, stream_key):
        # type: (string_types) -> None
        """Sets the stream_key of this LiveEncoding.

        Stream key of the live encoder (required)

        :param stream_key: The stream_key of this LiveEncoding.
        :type: string_types
        """

        if stream_key is not None:
            if not isinstance(stream_key, string_types):
                raise TypeError("Invalid type for `stream_key`, type has to be `string_types`")

        self._stream_key = stream_key

    @property
    def encoder_ip(self):
        # type: () -> string_types
        """Gets the encoder_ip of this LiveEncoding.

        IP address of the live encoder (required)

        :return: The encoder_ip of this LiveEncoding.
        :rtype: string_types
        """
        return self._encoder_ip

    @encoder_ip.setter
    def encoder_ip(self, encoder_ip):
        # type: (string_types) -> None
        """Sets the encoder_ip of this LiveEncoding.

        IP address of the live encoder (required)

        :param encoder_ip: The encoder_ip of this LiveEncoding.
        :type: string_types
        """

        if encoder_ip is not None:
            if not isinstance(encoder_ip, string_types):
                raise TypeError("Invalid type for `encoder_ip`, type has to be `string_types`")

        self._encoder_ip = encoder_ip

    @property
    def application(self):
        # type: () -> string_types
        """Gets the application of this LiveEncoding.

        This will indicate the application 'live'

        :return: The application of this LiveEncoding.
        :rtype: string_types
        """
        return self._application

    @application.setter
    def application(self, application):
        # type: (string_types) -> None
        """Sets the application of this LiveEncoding.

        This will indicate the application 'live'

        :param application: The application of this LiveEncoding.
        :type: string_types
        """

        if application is not None:
            if not isinstance(application, string_types):
                raise TypeError("Invalid type for `application`, type has to be `string_types`")

        self._application = application

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveEncoding):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.analytics.queries.count.count_api import CountApi
from bitmovin_api_sdk.analytics.queries.sum.sum_api import SumApi
from bitmovin_api_sdk.analytics.queries.avg.avg_api import AvgApi
from bitmovin_api_sdk.analytics.queries.min.min_api import MinApi
from bitmovin_api_sdk.analytics.queries.max.max_api import MaxApi
from bitmovin_api_sdk.analytics.queries.stddev.stddev_api import StddevApi
from bitmovin_api_sdk.analytics.queries.percentile.percentile_api import PercentileApi
from bitmovin_api_sdk.analytics.queries.variance.variance_api import VarianceApi
from bitmovin_api_sdk.analytics.queries.median.median_api import MedianApi


class QueriesApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(QueriesApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.count = CountApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.sum = SumApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.avg = AvgApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.min = MinApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.max = MaxApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.stddev = StddevApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.percentile = PercentileApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.variance = VarianceApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.median = MedianApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )



from bitmovin_api_sdk.encoding.encodings.muxings.mp3.mp3_api import Mp3Api
from bitmovin_api_sdk.encoding.encodings.muxings.mp3.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp3.information.information_api import InformationApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp3.mp3_muxing_list_query_params import Mp3MuxingListQueryParams



# coding: utf-8


from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.progressive_muxing_information import ProgressiveMuxingInformation
import pprint


class ProgressiveWavMuxingInformation(ProgressiveMuxingInformation):

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(ProgressiveWavMuxingInformation, self), "to_dict"):
            result = super(ProgressiveWavMuxingInformation, self).to_dict()
        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProgressiveWavMuxingInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.input import Input
import pprint
import six


class AsperaInput(Input):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 min_bandwidth=None,
                 max_bandwidth=None,
                 host=None,
                 username=None,
                 password=None,
                 token=None,
                 ssh_port=None,
                 fasp_port=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, string_types, string_types, string_types, string_types, string_types, int, int) -> None
        super(AsperaInput, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._min_bandwidth = None
        self._max_bandwidth = None
        self._host = None
        self._username = None
        self._password = None
        self._token = None
        self._ssh_port = None
        self._fasp_port = None
        self.discriminator = None

        if min_bandwidth is not None:
            self.min_bandwidth = min_bandwidth
        if max_bandwidth is not None:
            self.max_bandwidth = max_bandwidth
        if host is not None:
            self.host = host
        if username is not None:
            self.username = username
        if password is not None:
            self.password = password
        if token is not None:
            self.token = token
        if ssh_port is not None:
            self.ssh_port = ssh_port
        if fasp_port is not None:
            self.fasp_port = fasp_port

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(AsperaInput, self), 'openapi_types'):
            types = getattr(super(AsperaInput, self), 'openapi_types')

        types.update({
            'min_bandwidth': 'string_types',
            'max_bandwidth': 'string_types',
            'host': 'string_types',
            'username': 'string_types',
            'password': 'string_types',
            'token': 'string_types',
            'ssh_port': 'int',
            'fasp_port': 'int'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(AsperaInput, self), 'attribute_map'):
            attributes = getattr(super(AsperaInput, self), 'attribute_map')

        attributes.update({
            'min_bandwidth': 'minBandwidth',
            'max_bandwidth': 'maxBandwidth',
            'host': 'host',
            'username': 'username',
            'password': 'password',
            'token': 'token',
            'ssh_port': 'sshPort',
            'fasp_port': 'faspPort'
        })
        return attributes

    @property
    def min_bandwidth(self):
        # type: () -> string_types
        """Gets the min_bandwidth of this AsperaInput.

        Minimal download bandwidth. Examples: 100k, 100m, 100g

        :return: The min_bandwidth of this AsperaInput.
        :rtype: string_types
        """
        return self._min_bandwidth

    @min_bandwidth.setter
    def min_bandwidth(self, min_bandwidth):
        # type: (string_types) -> None
        """Sets the min_bandwidth of this AsperaInput.

        Minimal download bandwidth. Examples: 100k, 100m, 100g

        :param min_bandwidth: The min_bandwidth of this AsperaInput.
        :type: string_types
        """

        if min_bandwidth is not None:
            if not isinstance(min_bandwidth, string_types):
                raise TypeError("Invalid type for `min_bandwidth`, type has to be `string_types`")

        self._min_bandwidth = min_bandwidth

    @property
    def max_bandwidth(self):
        # type: () -> string_types
        """Gets the max_bandwidth of this AsperaInput.

        Maximal download bandwidth. Examples: 100k, 100m, 100g

        :return: The max_bandwidth of this AsperaInput.
        :rtype: string_types
        """
        return self._max_bandwidth

    @max_bandwidth.setter
    def max_bandwidth(self, max_bandwidth):
        # type: (string_types) -> None
        """Sets the max_bandwidth of this AsperaInput.

        Maximal download bandwidth. Examples: 100k, 100m, 100g

        :param max_bandwidth: The max_bandwidth of this AsperaInput.
        :type: string_types
        """

        if max_bandwidth is not None:
            if not isinstance(max_bandwidth, string_types):
                raise TypeError("Invalid type for `max_bandwidth`, type has to be `string_types`")

        self._max_bandwidth = max_bandwidth

    @property
    def host(self):
        # type: () -> string_types
        """Gets the host of this AsperaInput.

        Host to use for Aspera transfers (required)

        :return: The host of this AsperaInput.
        :rtype: string_types
        """
        return self._host

    @host.setter
    def host(self, host):
        # type: (string_types) -> None
        """Sets the host of this AsperaInput.

        Host to use for Aspera transfers (required)

        :param host: The host of this AsperaInput.
        :type: string_types
        """

        if host is not None:
            if not isinstance(host, string_types):
                raise TypeError("Invalid type for `host`, type has to be `string_types`")

        self._host = host

    @property
    def username(self):
        # type: () -> string_types
        """Gets the username of this AsperaInput.

        Username to log into Aspera host (either password and user must be set or token)

        :return: The username of this AsperaInput.
        :rtype: string_types
        """
        return self._username

    @username.setter
    def username(self, username):
        # type: (string_types) -> None
        """Sets the username of this AsperaInput.

        Username to log into Aspera host (either password and user must be set or token)

        :param username: The username of this AsperaInput.
        :type: string_types
        """

        if username is not None:
            if not isinstance(username, string_types):
                raise TypeError("Invalid type for `username`, type has to be `string_types`")

        self._username = username

    @property
    def password(self):
        # type: () -> string_types
        """Gets the password of this AsperaInput.

        corresponding password (either password and user must be set or token)

        :return: The password of this AsperaInput.
        :rtype: string_types
        """
        return self._password

    @password.setter
    def password(self, password):
        # type: (string_types) -> None
        """Sets the password of this AsperaInput.

        corresponding password (either password and user must be set or token)

        :param password: The password of this AsperaInput.
        :type: string_types
        """

        if password is not None:
            if not isinstance(password, string_types):
                raise TypeError("Invalid type for `password`, type has to be `string_types`")

        self._password = password

    @property
    def token(self):
        # type: () -> string_types
        """Gets the token of this AsperaInput.

        Token used for authentication (either password and user must be set or token)

        :return: The token of this AsperaInput.
        :rtype: string_types
        """
        return self._token

    @token.setter
    def token(self, token):
        # type: (string_types) -> None
        """Sets the token of this AsperaInput.

        Token used for authentication (either password and user must be set or token)

        :param token: The token of this AsperaInput.
        :type: string_types
        """

        if token is not None:
            if not isinstance(token, string_types):
                raise TypeError("Invalid type for `token`, type has to be `string_types`")

        self._token = token

    @property
    def ssh_port(self):
        # type: () -> int
        """Gets the ssh_port of this AsperaInput.

        Set the TCP port to be used for fasp session initiation

        :return: The ssh_port of this AsperaInput.
        :rtype: int
        """
        return self._ssh_port

    @ssh_port.setter
    def ssh_port(self, ssh_port):
        # type: (int) -> None
        """Sets the ssh_port of this AsperaInput.

        Set the TCP port to be used for fasp session initiation

        :param ssh_port: The ssh_port of this AsperaInput.
        :type: int
        """

        if ssh_port is not None:
            if not isinstance(ssh_port, int):
                raise TypeError("Invalid type for `ssh_port`, type has to be `int`")

        self._ssh_port = ssh_port

    @property
    def fasp_port(self):
        # type: () -> int
        """Gets the fasp_port of this AsperaInput.

        Set the UDP port to be used by fasp for data transfer

        :return: The fasp_port of this AsperaInput.
        :rtype: int
        """
        return self._fasp_port

    @fasp_port.setter
    def fasp_port(self, fasp_port):
        # type: (int) -> None
        """Sets the fasp_port of this AsperaInput.

        Set the UDP port to be used by fasp for data transfer

        :param fasp_port: The fasp_port of this AsperaInput.
        :type: int
        """

        if fasp_port is not None:
            if not isinstance(fasp_port, int):
                raise TypeError("Invalid type for `fasp_port`, type has to be `int`")

        self._fasp_port = fasp_port

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(AsperaInput, self), "to_dict"):
            result = super(AsperaInput, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AsperaInput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.transfer_error.transfer_error_api import TransferErrorApi
from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.transfer_error.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.transfer_error.webhook_list_query_params import WebhookListQueryParams
from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.transfer_error.webhook_list_by_encoding_id_query_params import WebhookListByEncodingIdQueryParams



from bitmovin_api_sdk.encoding.manifests.hls.streams.iframe.iframe_api import IframeApi
from bitmovin_api_sdk.encoding.manifests.hls.streams.iframe.i_frame_playlist_list_query_params import IFramePlaylistListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class H264NalHrd(Enum):
    NONE = "NONE"
    VBR = "VBR"
    CBR = "CBR"



from bitmovin_api_sdk.analytics.licenses.licenses_api import LicensesApi
from bitmovin_api_sdk.analytics.licenses.domains.domains_api import DomainsApi
from bitmovin_api_sdk.analytics.licenses.analytics_license_list_query_params import AnalyticsLicenseListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class StreamKeyType(Enum):
    RESERVED = "RESERVED"
    TEMPORARY = "TEMPORARY"



from bitmovin_api_sdk.analytics.outputs.gcs_service_account.gcs_service_account_api import GcsServiceAccountApi
from bitmovin_api_sdk.analytics.outputs.gcs_service_account.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.analytics.outputs.gcs_service_account.analytics_gcs_service_account_output_list_query_params import AnalyticsGcsServiceAccountOutputListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.cache_control import CacheControl
import pprint
import six


class CacheControlSettingsSegments(object):
    @poscheck_model
    def __init__(self,
                 init_segment=None,
                 media_segment=None):
        # type: (CacheControl, CacheControl) -> None

        self._init_segment = None
        self._media_segment = None
        self.discriminator = None

        if init_segment is not None:
            self.init_segment = init_segment
        if media_segment is not None:
            self.media_segment = media_segment

    @property
    def openapi_types(self):
        types = {
            'init_segment': 'CacheControl',
            'media_segment': 'CacheControl'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'init_segment': 'initSegment',
            'media_segment': 'mediaSegment'
        }
        return attributes

    @property
    def init_segment(self):
        # type: () -> CacheControl
        """Gets the init_segment of this CacheControlSettingsSegments.

        Cache control settings for init segment.

        :return: The init_segment of this CacheControlSettingsSegments.
        :rtype: CacheControl
        """
        return self._init_segment

    @init_segment.setter
    def init_segment(self, init_segment):
        # type: (CacheControl) -> None
        """Sets the init_segment of this CacheControlSettingsSegments.

        Cache control settings for init segment.

        :param init_segment: The init_segment of this CacheControlSettingsSegments.
        :type: CacheControl
        """

        if init_segment is not None:
            if not isinstance(init_segment, CacheControl):
                raise TypeError("Invalid type for `init_segment`, type has to be `CacheControl`")

        self._init_segment = init_segment

    @property
    def media_segment(self):
        # type: () -> CacheControl
        """Gets the media_segment of this CacheControlSettingsSegments.

        Cache control settings for media segment.

        :return: The media_segment of this CacheControlSettingsSegments.
        :rtype: CacheControl
        """
        return self._media_segment

    @media_segment.setter
    def media_segment(self, media_segment):
        # type: (CacheControl) -> None
        """Sets the media_segment of this CacheControlSettingsSegments.

        Cache control settings for media segment.

        :param media_segment: The media_segment of this CacheControlSettingsSegments.
        :type: CacheControl
        """

        if media_segment is not None:
            if not isinstance(media_segment, CacheControl):
                raise TypeError("Invalid type for `media_segment`, type has to be `CacheControl`")

        self._media_segment = media_segment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CacheControlSettingsSegments):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.manifests.hls.media.media_api import MediaApi
from bitmovin_api_sdk.encoding.manifests.hls.media.custom_tags.custom_tags_api import CustomTagsApi
from bitmovin_api_sdk.encoding.manifests.hls.media.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.manifests.hls.media.video.video_api import VideoApi
from bitmovin_api_sdk.encoding.manifests.hls.media.audio.audio_api import AudioApi
from bitmovin_api_sdk.encoding.manifests.hls.media.subtitles.subtitles_api import SubtitlesApi
from bitmovin_api_sdk.encoding.manifests.hls.media.vtt.vtt_api import VttApi
from bitmovin_api_sdk.encoding.manifests.hls.media.closed_captions.closed_captions_api import ClosedCaptionsApi



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.error_details import ErrorDetails
from bitmovin_api_sdk.models.status import Status
import pprint
import six


class Task(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 status=None,
                 eta=None,
                 progress=None,
                 subtasks=None,
                 messages=None,
                 created_at=None,
                 queued_at=None,
                 running_at=None,
                 finished_at=None,
                 error_at=None,
                 error=None):
        # type: (string_types, Status, float, int, list[Subtask], list[Message], datetime, datetime, datetime, datetime, datetime, ErrorDetails) -> None
        super(Task, self).__init__(id_=id_)

        self._status = None
        self._eta = None
        self._progress = None
        self._subtasks = list()
        self._messages = list()
        self._created_at = None
        self._queued_at = None
        self._running_at = None
        self._finished_at = None
        self._error_at = None
        self._error = None
        self.discriminator = None

        if status is not None:
            self.status = status
        if eta is not None:
            self.eta = eta
        if progress is not None:
            self.progress = progress
        if subtasks is not None:
            self.subtasks = subtasks
        if messages is not None:
            self.messages = messages
        if created_at is not None:
            self.created_at = created_at
        if queued_at is not None:
            self.queued_at = queued_at
        if running_at is not None:
            self.running_at = running_at
        if finished_at is not None:
            self.finished_at = finished_at
        if error_at is not None:
            self.error_at = error_at
        if error is not None:
            self.error = error

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Task, self), 'openapi_types'):
            types = getattr(super(Task, self), 'openapi_types')

        types.update({
            'status': 'Status',
            'eta': 'float',
            'progress': 'int',
            'subtasks': 'list[Subtask]',
            'messages': 'list[Message]',
            'created_at': 'datetime',
            'queued_at': 'datetime',
            'running_at': 'datetime',
            'finished_at': 'datetime',
            'error_at': 'datetime',
            'error': 'ErrorDetails'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Task, self), 'attribute_map'):
            attributes = getattr(super(Task, self), 'attribute_map')

        attributes.update({
            'status': 'status',
            'eta': 'eta',
            'progress': 'progress',
            'subtasks': 'subtasks',
            'messages': 'messages',
            'created_at': 'createdAt',
            'queued_at': 'queuedAt',
            'running_at': 'runningAt',
            'finished_at': 'finishedAt',
            'error_at': 'errorAt',
            'error': 'error'
        })
        return attributes

    @property
    def status(self):
        # type: () -> Status
        """Gets the status of this Task.

        Current status (required)

        :return: The status of this Task.
        :rtype: Status
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: (Status) -> None
        """Sets the status of this Task.

        Current status (required)

        :param status: The status of this Task.
        :type: Status
        """

        if status is not None:
            if not isinstance(status, Status):
                raise TypeError("Invalid type for `status`, type has to be `Status`")

        self._status = status

    @property
    def eta(self):
        # type: () -> float
        """Gets the eta of this Task.

        Estimated ETA in seconds

        :return: The eta of this Task.
        :rtype: float
        """
        return self._eta

    @eta.setter
    def eta(self, eta):
        # type: (float) -> None
        """Sets the eta of this Task.

        Estimated ETA in seconds

        :param eta: The eta of this Task.
        :type: float
        """

        if eta is not None:
            if not isinstance(eta, (float, int)):
                raise TypeError("Invalid type for `eta`, type has to be `float`")

        self._eta = eta

    @property
    def progress(self):
        # type: () -> int
        """Gets the progress of this Task.

        Progress in percent

        :return: The progress of this Task.
        :rtype: int
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        # type: (int) -> None
        """Sets the progress of this Task.

        Progress in percent

        :param progress: The progress of this Task.
        :type: int
        """

        if progress is not None:
            if not isinstance(progress, int):
                raise TypeError("Invalid type for `progress`, type has to be `int`")

        self._progress = progress

    @property
    def subtasks(self):
        # type: () -> list[Subtask]
        """Gets the subtasks of this Task.

        List of subtasks

        :return: The subtasks of this Task.
        :rtype: list[Subtask]
        """
        return self._subtasks

    @subtasks.setter
    def subtasks(self, subtasks):
        # type: (list) -> None
        """Sets the subtasks of this Task.

        List of subtasks

        :param subtasks: The subtasks of this Task.
        :type: list[Subtask]
        """

        if subtasks is not None:
            if not isinstance(subtasks, list):
                raise TypeError("Invalid type for `subtasks`, type has to be `list[Subtask]`")

        self._subtasks = subtasks

    @property
    def messages(self):
        # type: () -> list[Message]
        """Gets the messages of this Task.

        Task specific messages

        :return: The messages of this Task.
        :rtype: list[Message]
        """
        return self._messages

    @messages.setter
    def messages(self, messages):
        # type: (list) -> None
        """Sets the messages of this Task.

        Task specific messages

        :param messages: The messages of this Task.
        :type: list[Message]
        """

        if messages is not None:
            if not isinstance(messages, list):
                raise TypeError("Invalid type for `messages`, type has to be `list[Message]`")

        self._messages = messages

    @property
    def created_at(self):
        # type: () -> datetime
        """Gets the created_at of this Task.

        Timestamp when the task was created, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :return: The created_at of this Task.
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        # type: (datetime) -> None
        """Sets the created_at of this Task.

        Timestamp when the task was created, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :param created_at: The created_at of this Task.
        :type: datetime
        """

        if created_at is not None:
            if not isinstance(created_at, datetime):
                raise TypeError("Invalid type for `created_at`, type has to be `datetime`")

        self._created_at = created_at

    @property
    def queued_at(self):
        # type: () -> datetime
        """Gets the queued_at of this Task.

        Timestamp when the task status changed to \"QUEUED\", returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :return: The queued_at of this Task.
        :rtype: datetime
        """
        return self._queued_at

    @queued_at.setter
    def queued_at(self, queued_at):
        # type: (datetime) -> None
        """Sets the queued_at of this Task.

        Timestamp when the task status changed to \"QUEUED\", returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :param queued_at: The queued_at of this Task.
        :type: datetime
        """

        if queued_at is not None:
            if not isinstance(queued_at, datetime):
                raise TypeError("Invalid type for `queued_at`, type has to be `datetime`")

        self._queued_at = queued_at

    @property
    def running_at(self):
        # type: () -> datetime
        """Gets the running_at of this Task.

        Timestamp when the task status changed to \"RUNNING\", returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :return: The running_at of this Task.
        :rtype: datetime
        """
        return self._running_at

    @running_at.setter
    def running_at(self, running_at):
        # type: (datetime) -> None
        """Sets the running_at of this Task.

        Timestamp when the task status changed to \"RUNNING\", returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :param running_at: The running_at of this Task.
        :type: datetime
        """

        if running_at is not None:
            if not isinstance(running_at, datetime):
                raise TypeError("Invalid type for `running_at`, type has to be `datetime`")

        self._running_at = running_at

    @property
    def finished_at(self):
        # type: () -> datetime
        """Gets the finished_at of this Task.

        Timestamp when the subtask status changed to a final state like 'FINISHED', 'ERROR', 'CANCELED', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ  Note that this timestamp might be inaccurate for tasks which ran prior to the [1.50.0 REST API release](https://bitmovin.com/docs/encoding/changelogs/rest). 

        :return: The finished_at of this Task.
        :rtype: datetime
        """
        return self._finished_at

    @finished_at.setter
    def finished_at(self, finished_at):
        # type: (datetime) -> None
        """Sets the finished_at of this Task.

        Timestamp when the subtask status changed to a final state like 'FINISHED', 'ERROR', 'CANCELED', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ  Note that this timestamp might be inaccurate for tasks which ran prior to the [1.50.0 REST API release](https://bitmovin.com/docs/encoding/changelogs/rest). 

        :param finished_at: The finished_at of this Task.
        :type: datetime
        """

        if finished_at is not None:
            if not isinstance(finished_at, datetime):
                raise TypeError("Invalid type for `finished_at`, type has to be `datetime`")

        self._finished_at = finished_at

    @property
    def error_at(self):
        # type: () -> datetime
        """Gets the error_at of this Task.

        Timestamp when the subtask status changed to 'ERROR', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ  Note that this timestamp is deprecated and is equivalent to finishedAt in case of an 'ERROR'. 

        :return: The error_at of this Task.
        :rtype: datetime
        """
        return self._error_at

    @error_at.setter
    def error_at(self, error_at):
        # type: (datetime) -> None
        """Sets the error_at of this Task.

        Timestamp when the subtask status changed to 'ERROR', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ  Note that this timestamp is deprecated and is equivalent to finishedAt in case of an 'ERROR'. 

        :param error_at: The error_at of this Task.
        :type: datetime
        """

        if error_at is not None:
            if not isinstance(error_at, datetime):
                raise TypeError("Invalid type for `error_at`, type has to be `datetime`")

        self._error_at = error_at

    @property
    def error(self):
        # type: () -> ErrorDetails
        """Gets the error of this Task.

        Additional optional error details

        :return: The error of this Task.
        :rtype: ErrorDetails
        """
        return self._error

    @error.setter
    def error(self, error):
        # type: (ErrorDetails) -> None
        """Sets the error of this Task.

        Additional optional error details

        :param error: The error of this Task.
        :type: ErrorDetails
        """

        if error is not None:
            if not isinstance(error, ErrorDetails):
                raise TypeError("Invalid type for `error`, type has to be `ErrorDetails`")

        self._error = error

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Task, self), "to_dict"):
            result = super(Task, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Task):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.notification import Notification
from bitmovin_api_sdk.models.webhook_http_method import WebhookHttpMethod
from bitmovin_api_sdk.models.webhook_signature import WebhookSignature
import pprint
import six


class WebhookNotification(Notification):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 resolve=None,
                 resource_id=None,
                 triggered_at=None,
                 type_=None,
                 event_type=None,
                 category=None,
                 resource_type=None,
                 muted=None,
                 custom_data=None,
                 url=None,
                 method=None,
                 insecure_ssl=None,
                 signature=None):
        # type: (string_types, bool, string_types, datetime, string_types, string_types, string_types, string_types, bool, dict, string_types, WebhookHttpMethod, bool, WebhookSignature) -> None
        super(WebhookNotification, self).__init__(id_=id_, resolve=resolve, resource_id=resource_id, triggered_at=triggered_at, type_=type_, event_type=event_type, category=category, resource_type=resource_type, muted=muted, custom_data=custom_data)

        self._url = None
        self._method = None
        self._insecure_ssl = None
        self._signature = None
        self.discriminator = None

        if url is not None:
            self.url = url
        if method is not None:
            self.method = method
        if insecure_ssl is not None:
            self.insecure_ssl = insecure_ssl
        if signature is not None:
            self.signature = signature

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(WebhookNotification, self), 'openapi_types'):
            types = getattr(super(WebhookNotification, self), 'openapi_types')

        types.update({
            'url': 'string_types',
            'method': 'WebhookHttpMethod',
            'insecure_ssl': 'bool',
            'signature': 'WebhookSignature'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(WebhookNotification, self), 'attribute_map'):
            attributes = getattr(super(WebhookNotification, self), 'attribute_map')

        attributes.update({
            'url': 'url',
            'method': 'method',
            'insecure_ssl': 'insecureSsl',
            'signature': 'signature'
        })
        return attributes

    @property
    def url(self):
        # type: () -> string_types
        """Gets the url of this WebhookNotification.

        The destination URL where the webhook data is send to (required)

        :return: The url of this WebhookNotification.
        :rtype: string_types
        """
        return self._url

    @url.setter
    def url(self, url):
        # type: (string_types) -> None
        """Sets the url of this WebhookNotification.

        The destination URL where the webhook data is send to (required)

        :param url: The url of this WebhookNotification.
        :type: string_types
        """

        if url is not None:
            if not isinstance(url, string_types):
                raise TypeError("Invalid type for `url`, type has to be `string_types`")

        self._url = url

    @property
    def method(self):
        # type: () -> WebhookHttpMethod
        """Gets the method of this WebhookNotification.

        HTTP method used for the webhook

        :return: The method of this WebhookNotification.
        :rtype: WebhookHttpMethod
        """
        return self._method

    @method.setter
    def method(self, method):
        # type: (WebhookHttpMethod) -> None
        """Sets the method of this WebhookNotification.

        HTTP method used for the webhook

        :param method: The method of this WebhookNotification.
        :type: WebhookHttpMethod
        """

        if method is not None:
            if not isinstance(method, WebhookHttpMethod):
                raise TypeError("Invalid type for `method`, type has to be `WebhookHttpMethod`")

        self._method = method

    @property
    def insecure_ssl(self):
        # type: () -> bool
        """Gets the insecure_ssl of this WebhookNotification.

        Skip verification of the SSL certificate

        :return: The insecure_ssl of this WebhookNotification.
        :rtype: bool
        """
        return self._insecure_ssl

    @insecure_ssl.setter
    def insecure_ssl(self, insecure_ssl):
        # type: (bool) -> None
        """Sets the insecure_ssl of this WebhookNotification.

        Skip verification of the SSL certificate

        :param insecure_ssl: The insecure_ssl of this WebhookNotification.
        :type: bool
        """

        if insecure_ssl is not None:
            if not isinstance(insecure_ssl, bool):
                raise TypeError("Invalid type for `insecure_ssl`, type has to be `bool`")

        self._insecure_ssl = insecure_ssl

    @property
    def signature(self):
        # type: () -> WebhookSignature
        """Gets the signature of this WebhookNotification.

        Signature used for the webhook

        :return: The signature of this WebhookNotification.
        :rtype: WebhookSignature
        """
        return self._signature

    @signature.setter
    def signature(self, signature):
        # type: (WebhookSignature) -> None
        """Sets the signature of this WebhookNotification.

        Signature used for the webhook

        :param signature: The signature of this WebhookNotification.
        :type: WebhookSignature
        """

        if signature is not None:
            if not isinstance(signature, WebhookSignature):
                raise TypeError("Invalid type for `signature`, type has to be `WebhookSignature`")

        self._signature = signature

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(WebhookNotification, self), "to_dict"):
            result = super(WebhookNotification, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookNotification):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.inputs.srt.srt_api import SrtApi
from bitmovin_api_sdk.encoding.inputs.srt.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.inputs.srt.srt_input_list_query_params import SrtInputListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.broadcast_ts_input_stream_configuration import BroadcastTsInputStreamConfiguration
from bitmovin_api_sdk.models.rai_unit import RaiUnit
import pprint
import six


class BroadcastTsAudioInputStreamConfiguration(BroadcastTsInputStreamConfiguration):
    @poscheck_model
    def __init__(self,
                 stream_id=None,
                 packet_identifier=None,
                 start_with_discontinuity_indicator=None,
                 align_pes=None,
                 set_rai_on_au=None,
                 use_atsc_buffer_model=None,
                 language=None):
        # type: (string_types, int, bool, bool, RaiUnit, bool, string_types) -> None
        super(BroadcastTsAudioInputStreamConfiguration, self).__init__(stream_id=stream_id, packet_identifier=packet_identifier, start_with_discontinuity_indicator=start_with_discontinuity_indicator, align_pes=align_pes, set_rai_on_au=set_rai_on_au)

        self._use_atsc_buffer_model = None
        self._language = None
        self.discriminator = None

        if use_atsc_buffer_model is not None:
            self.use_atsc_buffer_model = use_atsc_buffer_model
        if language is not None:
            self.language = language

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(BroadcastTsAudioInputStreamConfiguration, self), 'openapi_types'):
            types = getattr(super(BroadcastTsAudioInputStreamConfiguration, self), 'openapi_types')

        types.update({
            'use_atsc_buffer_model': 'bool',
            'language': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(BroadcastTsAudioInputStreamConfiguration, self), 'attribute_map'):
            attributes = getattr(super(BroadcastTsAudioInputStreamConfiguration, self), 'attribute_map')

        attributes.update({
            'use_atsc_buffer_model': 'useATSCBufferModel',
            'language': 'language'
        })
        return attributes

    @property
    def use_atsc_buffer_model(self):
        # type: () -> bool
        """Gets the use_atsc_buffer_model of this BroadcastTsAudioInputStreamConfiguration.

        Use ATSC buffer model for AC-3. If true, use the ATSC version of the T-STD buffer model is used. This parameter applies to AC-3 streams only.

        :return: The use_atsc_buffer_model of this BroadcastTsAudioInputStreamConfiguration.
        :rtype: bool
        """
        return self._use_atsc_buffer_model

    @use_atsc_buffer_model.setter
    def use_atsc_buffer_model(self, use_atsc_buffer_model):
        # type: (bool) -> None
        """Sets the use_atsc_buffer_model of this BroadcastTsAudioInputStreamConfiguration.

        Use ATSC buffer model for AC-3. If true, use the ATSC version of the T-STD buffer model is used. This parameter applies to AC-3 streams only.

        :param use_atsc_buffer_model: The use_atsc_buffer_model of this BroadcastTsAudioInputStreamConfiguration.
        :type: bool
        """

        if use_atsc_buffer_model is not None:
            if not isinstance(use_atsc_buffer_model, bool):
                raise TypeError("Invalid type for `use_atsc_buffer_model`, type has to be `bool`")

        self._use_atsc_buffer_model = use_atsc_buffer_model

    @property
    def language(self):
        # type: () -> string_types
        """Gets the language of this BroadcastTsAudioInputStreamConfiguration.

        Language of the audio stream. Specified according to the ISO 639-2 alpha code for the language descriptor.

        :return: The language of this BroadcastTsAudioInputStreamConfiguration.
        :rtype: string_types
        """
        return self._language

    @language.setter
    def language(self, language):
        # type: (string_types) -> None
        """Sets the language of this BroadcastTsAudioInputStreamConfiguration.

        Language of the audio stream. Specified according to the ISO 639-2 alpha code for the language descriptor.

        :param language: The language of this BroadcastTsAudioInputStreamConfiguration.
        :type: string_types
        """

        if language is not None:
            if not isinstance(language, string_types):
                raise TypeError("Invalid type for `language`, type has to be `string_types`")

        self._language = language

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(BroadcastTsAudioInputStreamConfiguration, self), "to_dict"):
            result = super(BroadcastTsAudioInputStreamConfiguration, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BroadcastTsAudioInputStreamConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.live_standby_pool_encoding import LiveStandbyPoolEncoding
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.live.standby_pools.encodings.live_standby_pool_encoding_list_query_params import LiveStandbyPoolEncodingListQueryParams


class EncodingsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(EncodingsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def delete(self, pool_id, id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete encoding from pool by id

        :param pool_id: Id of the standby pool
        :type pool_id: string_types, required
        :param id: Id of the standby pool encoding
        :type id: string_types, required
        :return: Id of the encoding from the pool that was deleted
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/live/standby-pools/{pool_id}/encodings/{id}',
            path_params={'pool_id': pool_id, 'id': id},
            type=BitmovinResponse,
            **kwargs
        )

    def list(self, pool_id, query_params=None, **kwargs):
        # type: (string_types, LiveStandbyPoolEncodingListQueryParams, dict) -> LiveStandbyPoolEncoding
        """List encodings from a standby pool

        :param pool_id: Id of the standby pool
        :type pool_id: string_types, required
        :param query_params: Query parameters
        :type query_params: LiveStandbyPoolEncodingListQueryParams
        :return: Standby pool encodings list response
        :rtype: LiveStandbyPoolEncoding
        """

        return self.api_client.get(
            '/encoding/live/standby-pools/{pool_id}/encodings',
            path_params={'pool_id': pool_id},
            query_params=query_params,
            pagination_response=True,
            type=LiveStandbyPoolEncoding,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.manifest_type import ManifestType
from bitmovin_api_sdk.models.status import Status
import pprint
import six


class Manifest(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 type_=None,
                 outputs=None,
                 status=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, ManifestType, list[EncodingOutput], Status) -> None
        super(Manifest, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._type = None
        self._outputs = list()
        self._status = None
        self.discriminator = None

        if type_ is not None:
            self.type = type_
        if outputs is not None:
            self.outputs = outputs
        if status is not None:
            self.status = status

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Manifest, self), 'openapi_types'):
            types = getattr(super(Manifest, self), 'openapi_types')

        types.update({
            'type': 'ManifestType',
            'outputs': 'list[EncodingOutput]',
            'status': 'Status'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Manifest, self), 'attribute_map'):
            attributes = getattr(super(Manifest, self), 'attribute_map')

        attributes.update({
            'type': 'type',
            'outputs': 'outputs',
            'status': 'status'
        })
        return attributes

    @property
    def type(self):
        # type: () -> ManifestType
        """Gets the type of this Manifest.


        :return: The type of this Manifest.
        :rtype: ManifestType
        """
        return self._type

    @type.setter
    def type(self, type_):
        # type: (ManifestType) -> None
        """Sets the type of this Manifest.


        :param type_: The type of this Manifest.
        :type: ManifestType
        """

        if type_ is not None:
            if not isinstance(type_, ManifestType):
                raise TypeError("Invalid type for `type`, type has to be `ManifestType`")

        self._type = type_

    @property
    def outputs(self):
        # type: () -> list[EncodingOutput]
        """Gets the outputs of this Manifest.

        The outputs to store the manifest (required)

        :return: The outputs of this Manifest.
        :rtype: list[EncodingOutput]
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        # type: (list) -> None
        """Sets the outputs of this Manifest.

        The outputs to store the manifest (required)

        :param outputs: The outputs of this Manifest.
        :type: list[EncodingOutput]
        """

        if outputs is not None:
            if not isinstance(outputs, list):
                raise TypeError("Invalid type for `outputs`, type has to be `list[EncodingOutput]`")

        self._outputs = outputs

    @property
    def status(self):
        # type: () -> Status
        """Gets the status of this Manifest.

        Current status

        :return: The status of this Manifest.
        :rtype: Status
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: (Status) -> None
        """Sets the status of this Manifest.

        Current status

        :param status: The status of this Manifest.
        :type: Status
        """

        if status is not None:
            if not isinstance(status, Status):
                raise TypeError("Invalid type for `status`, type has to be `Status`")

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Manifest, self), "to_dict"):
            result = super(Manifest, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Manifest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
